@@ -30,7 +30,7 @@ SOFTWARE.
 
 
 # Import third-party modules.
-from typing import Any, List, Dict
+from typing import Any, List, Dict, Union
 
 # Import local modules.
 from avro import config
@@ -44,7 +44,7 @@ RULE_PATTERNS: list = [p for p in PATTERNS if 'rules' in p]
 
 
 # The primary parse function for the library.
-def parse(*texts: str) -> str | List[str]:
+def parse(*texts: str) -> Union[str, List[str]]:
     '''
     ### Parses input text, matches and replaces using avrodict.
 
@@ -181,7 +181,7 @@ def exact_find_in_pattern(fixed_text: str, cur: int=0, patterns: Any=PATTERNS) -
     ]
 
 
-def process_rules(rules: Any, fixed_text: str, cur: int=0, cur_end: int=1) -> Any | None:
+def process_rules(rules: Any, fixed_text: str, cur: int=0, cur_end: int=1) -> Union[Any, None]:
     '''
     ### Process rules matched in pattern and returns suitable replacement.
 
